==> nextcloud-22.2.6.tgz: nextcloud/apps/dav/l10n/zh_CN.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Todos" : "待办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 还原了日历 {calendar}",
    "You restored calendar {calendar}" : "你还原了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "你取消了 {actor} 共享的日历 {calendar}",
    "You unshared calendar {calendar} from {user}" : "{user} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{user} 取消了 {actor} 共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消了他们自己共享的日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "群组 {group} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "群组 {group} 取消了 {actor} 共享的日历 {calendar}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 还原了事件 {event}，它位于日历 {calendar}",
    "You restored event {event} of calendar {calendar}" : "你还原了事件 {event}，它位于日历 {calendar}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "Calendar, contacts and tasks" : "日历、联系人和任务",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Contact birthdays" : "联系人生日",
    "Death of %s" : "%s 的忌日",
    "Calendar:" : "日历：",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "Untitled event" : "未命名事件",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n minute_::_%n minutes_" : ["%n 分钟"],
    "%s (in %s)" : "%s （在 %s）",
    "%s (%s ago)" : "%s （%s 前）",
    "Calendar: %s" : "日历：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地点：%s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Cancelled: %1$s" : "已取消：%1$s",
    "Invitation canceled" : "邀请已取消",
    "Re: %1$s" : "回复：%1$s",
    "Invitation updated" : "邀请已更新",
    "Invitation: %1$s" : "邀请：%1$s",
    "Invitation" : "邀请",
    "Title:" : "标题：",
    "Time:" : "时间：",
    "Location:" : "地区：",
    "Link:" : "链接：",
    "Organizer:" : "组织者：",
    "Attendees:" : "与会者：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "More options at %s" : "在%s的更多选项",
    "Contacts" : "联系人",
    "{actor} created address book {addressbook}" : "{actor} 创建了通讯录 {addressbook}",
    "You created address book {addressbook}" : "你创建了通讯录 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 删除了通讯录 {addressbook}",
    "You deleted address book {addressbook}" : "你删除了通讯录 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通讯录 {addressbook}",
    "You updated address book {addressbook}" : "你更新通讯录  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 与你分享了通讯录 {addressbook}",
    "You shared address book {addressbook} with {user}" : "你与 {user} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 与 {user} 分享了通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消和你分享通讯录 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "你取消了与 {user} 分享通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消了与 {user} 分享通讯录",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消了和自己分享通讯录 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "你和小组 {group} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 和小组 {group} 分享了通讯录 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "你取消和小组 {group} 分享通讯录 ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消和小组 {group} 分享通讯录 ",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通讯录 {addressbook} 中创建了联系人 {card} ",
    "You created contact {card} in address book {addressbook}" : "你在通讯录 {addressbook} 中创建了联系人 {card} ",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 从通讯录 {addressbook} 中删除了联系人 {card} ",
    "You deleted contact {card} from address book {addressbook}" : "你从通讯录 {addressbook} 中删除了联系人 {card} ",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通讯录 {addressbook} 中的联系人 {card} ",
    "You updated contact {card} in address book {addressbook}" : "你更新了通讯录 {addressbook} 中的联系人 {card} ",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "一名 <strong>联系人</strong>或一个<strong>通讯录</strong>被更改了",
    "System is in maintenance mode." : "系统处于维护模式 ",
    "Upgrade needed" : "需要升级",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的%s 需要配置使用HTTPS以在iOS/macOS中使用CalDAV和CardDAV。",
    "Configures a CalDAV account" : "配置一个 CalDAV 账号",
    "Configures a CardDAV account" : "配置一个 CardDAV 账号",
    "Events" : "事件",
    "Tasks" : "任务",
    "Untitled task" : "无标题任务",
    "Completed on %s" : "已完成 %s",
    "Due on %s by %s" : "到期于%s ，在%s之前",
    "Due on %s" : "到期于%s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV端点",
    "Availability" : "可用性",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "如果您配置了工作时间，其他用户在预订会议时就会了解您何时不在办公室。",
    "Time zone:" : "时区：",
    "to" : "到",
    "Delete slot" : "删除插槽",
    "No working hours set" : "尚未设置工作时间",
    "Add slot" : "添加插槽",
    "Monday" : "周一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "Save" : "保存",
    "Calendar server" : "日历服务器",
    "Send invitations to attendees" : "向与会者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "Send notifications for events" : "发送事件通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
    "Enable notifications for events via push" : "启用推送事件通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装 {calendarappstoreopen}日历应用{linkclose}，或者 {calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置 {emailopen}邮件服务器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的出席状态时出错。",
    "Please contact the organizer directly." : "请直接联系组织者。",
    "Are you accepting the invitation?" : "您是否接受邀请？",
    "Tentative" : "暂定",
    "Number of guests" : "客人数目",
    "Comment" : "备注",
    "Your attendance was updated successfully." : "您的出席状态更新成功。",
    "Calendar and tasks" : "日历和任务"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.9.tgz: nextcloud/apps/dav/l10n/zh_CN.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "日历",
    "Todos" : "待办事项",
    "Personal" : "个人",
    "{actor} created calendar {calendar}" : "{actor} 创建了日历 {calendar}",
    "You created calendar {calendar}" : "您创建的日历 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 删除了日历 {calendar}",
    "You deleted calendar {calendar}" : "您删除的日历 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日历 {calendar}",
    "You updated calendar {calendar}" : "您更新了日历 {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} 还原了日历 {calendar}",
    "You restored calendar {calendar}" : "你还原了日历 {calendar}",
    "You shared calendar {calendar} as public link" : "您已将日历 {calendar} 共享为公开链接",
    "You removed public link for calendar {calendar}" : "您移除了日历 {calendar} 的公开链接",
    "{actor} shared calendar {calendar} with you" : "{actor} 收到的日历共享 {calendar}",
    "You shared calendar {calendar} with {user}" : "您与 {user} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 与 {user} 共享了日历 {calendar}",
    "{actor} unshared calendar {calendar} from you" : "你取消了 {actor} 共享的日历 {calendar}",
    "You unshared calendar {calendar} from {user}" : "{user} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{user} 取消了 {actor} 共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 取消了他们自己共享的日历 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您通过组 {group} 共享了日历 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 通过组 {group} 共享了日历 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "群组 {group} 取消了你共享的日历 {calendar}",
    "{actor} unshared calendar {calendar} from group {group}" : "群组 {group} 取消了 {actor} 共享的日历 {calendar}",
    "Untitled event" : "未命名事件",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中创建了事件 {event}",
    "You created event {event} in calendar {calendar}" : "您在日历 {calendar} 中创建了事件 {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 在日历 {calendar} 中删除了事件 {event}",
    "You deleted event {event} from calendar {calendar}" : "您在日历 {calendar} 中删除了事件 {event}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 在日历 {calendar} 中更新了事件 {event}",
    "You updated event {event} in calendar {calendar}" : "您在日历 {calendar} 中更新了事件 {event}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} 还原了事件 {event}，它位于日历 {calendar}",
    "You restored event {event} of calendar {calendar}" : "你还原了事件 {event}，它位于日历 {calendar}",
    "Busy" : "忙碌",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中创建了待办事项 {todo}",
    "You created todo {todo} in list {calendar}" : "您在列表 {calendar} 中创建了待办事项 {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 在列表 {calendar} 中删除了待办事项 {todo}",
    "You deleted todo {todo} from list {calendar}" : "您在列表 {calendar} 中删除了待办事项 {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中更新了待办事项 {todo}",
    "You updated todo {todo} in list {calendar}" : "您在列表 {calendar} 中更新了待办事项 {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中解决了待办事项 {todo}",
    "You solved todo {todo} in list {calendar}" : "您在列表 {calendar} 中解决了待办事项 {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 在列表 {calendar} 中重新打开了待办事项 {todo}",
    "You reopened todo {todo} in list {calendar}" : "您在列表 {calendar} 中重新打开了待办事项 {todo}",
    "Calendar, contacts and tasks" : "日历、联系人和任务",
    "A <strong>calendar</strong> was modified" : "<strong>日历</strong>已经修改",
    "A calendar <strong>event</strong> was modified" : "日历中<strong>事件</strong>已经修改",
    "A calendar <strong>todo</strong> was modified" : "列表中<strong>待办事项</strong>已经修改",
    "Contact birthdays" : "联系人生日",
    "Death of %s" : "%s 的忌日",
    "Calendar:" : "日历：",
    "Date:" : "日期：",
    "Where:" : "地点：",
    "Description:" : "描述：",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n day_::_%n days_" : ["%n 天"],
    "_%n hour_::_%n hours_" : ["%n 小时"],
    "_%n minute_::_%n minutes_" : ["%n 分钟"],
    "%s (in %s)" : "%s （在 %s）",
    "%s (%s ago)" : "%s （%s 前）",
    "Calendar: %s" : "日历：%s",
    "Date: %s" : "日期：%s",
    "Description: %s" : "描述：%s",
    "Where: %s" : "地点：%s",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Cancelled: %1$s" : "已取消：%1$s",
    "Invitation canceled" : "邀请已取消",
    "Re: %1$s" : "回复：%1$s",
    "Invitation updated" : "邀请已更新",
    "Invitation: %1$s" : "邀请：%1$s",
    "Invitation" : "邀请",
    "Title:" : "标题：",
    "Time:" : "时间：",
    "Location:" : "地区：",
    "Link:" : "链接：",
    "Organizer:" : "组织者：",
    "Attendees:" : "与会者：",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options …" : "更多选项",
    "More options at %s" : "在%s的更多选项",
    "Contacts" : "联系人",
    "{actor} created address book {addressbook}" : "{actor} 创建了通讯录 {addressbook}",
    "You created address book {addressbook}" : "你创建了通讯录 {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} 删除了通讯录 {addressbook}",
    "You deleted address book {addressbook}" : "你删除了通讯录 {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} 更新了通讯录 {addressbook}",
    "You updated address book {addressbook}" : "你更新通讯录  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} 与你分享了通讯录 {addressbook}",
    "You shared address book {addressbook} with {user}" : "你与 {user} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} 与 {user} 分享了通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} 取消和你分享通讯录 {addressbook}",
    "You unshared address book {addressbook} from {user}" : "你取消了与 {user} 分享通讯录 {addressbook}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} 取消了与 {user} 分享通讯录",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} 取消了和自己分享通讯录 {addressbook}",
    "You shared address book {addressbook} with group {group}" : "你和小组 {group} 分享了通讯录 {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} 和小组 {group} 分享了通讯录 {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "你取消和小组 {group} 分享通讯录 ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} 取消和小组 {group} 分享通讯录 ",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} 在通讯录 {addressbook} 中创建了联系人 {card} ",
    "You created contact {card} in address book {addressbook}" : "你在通讯录 {addressbook} 中创建了联系人 {card} ",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} 从通讯录 {addressbook} 中删除了联系人 {card} ",
    "You deleted contact {card} from address book {addressbook}" : "你从通讯录 {addressbook} 中删除了联系人 {card} ",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通讯录 {addressbook} 中的联系人 {card} ",
    "You updated contact {card} in address book {addressbook}" : "你更新了通讯录 {addressbook} 中的联系人 {card} ",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "一名 <strong>联系人</strong>或一个<strong>通讯录</strong>被更改了",
    "System is in maintenance mode." : "系统处于维护模式 ",
    "Upgrade needed" : "需要升级",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的%s 需要配置使用HTTPS以在iOS/macOS中使用CalDAV和CardDAV。",
    "Configures a CalDAV account" : "配置一个 CalDAV 账号",
    "Configures a CardDAV account" : "配置一个 CardDAV 账号",
    "Events" : "事件",
    "Tasks" : "任务",
    "Untitled task" : "无标题任务",
    "Completed on %s" : "已完成 %s",
    "Due on %s by %s" : "到期于%s ，在%s之前",
    "Due on %s" : "到期于%s",
    "Contacts and groups" : "联系人和群组",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV端点",
    "Availability" : "可用性",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "如果您配置了工作时间，其他用户在预订会议时就会了解您何时不在办公室。",
    "Time zone:" : "时区：",
    "to" : "到",
    "Delete slot" : "删除插槽",
    "No working hours set" : "尚未设置工作时间",
    "Add slot" : "添加插槽",
    "Monday" : "周一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "Save" : "保存",
    "Calendar server" : "日历服务器",
    "Send invitations to attendees" : "向与会者发送邀请",
    "Automatically generate a birthday calendar" : "自动生成生日日历",
    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
    "Send notifications for events" : "发送事件通知",
    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
    "Enable notifications for events via push" : "启用推送事件通知",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装 {calendarappstoreopen}日历应用{linkclose}，或者 {calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置 {emailopen}邮件服务器{linkclose}。",
    "There was an error updating your attendance status." : "更新您的出席状态时出错。",
    "Please contact the organizer directly." : "请直接联系组织者。",
    "Are you accepting the invitation?" : "您是否接受邀请？",
    "Tentative" : "暂定",
    "Number of guests" : "客人数目",
    "Comment" : "备注",
    "Your attendance was updated successfully." : "您的出席状态更新成功。"
},
"nplurals=1; plural=0;");
